@@ -26,7 +26,10 @@ typedef enum _GrdDebugFlags
   GRD_DEBUG_NONE = 0,
   GRD_DEBUG_VNC = 1 << 0,
   GRD_DEBUG_TPM = 1 << 1,
-  GRD_DEBUG_RDP_LEGACY_GRAPHICS = 1 << 2,
+  GRD_DEBUG_VK_VALIDATION = 1 << 2,
+  GRD_DEBUG_VK_TIMES = 1 << 3,
+  GRD_DEBUG_VA_TIMES = 1 << 4,
+  GRD_DEBUG_VKVA = 1 << 5,
 } GrdDebugFlags;
 
 GrdDebugFlags grd_get_debug_flags (void);
