@@ -40,8 +40,6 @@ struct _GrdRdpGfxSurface
   uint16_t width;
   uint16_t height;
 
-  gboolean is_auxiliary_surface;
-
   GrdRdpGfxSurface *render_surface;
 
   GrdRdpGfxFrameController *frame_controller;
@@ -85,12 +83,6 @@ grd_rdp_gfx_surface_get_height (GrdRdpGfxSurface *gfx_surface)
   return gfx_surface->height;
 }
 
-gboolean
-grd_rdp_gfx_surface_is_auxiliary_surface (GrdRdpGfxSurface *gfx_surface)
-{
-  return gfx_surface->is_auxiliary_surface;
-}
-
 gboolean
 grd_rdp_gfx_surface_disallows_hwaccel_sessions (GrdRdpGfxSurface *gfx_surface)
 {
@@ -113,7 +105,6 @@ grd_rdp_gfx_surface_override_render_surface (GrdRdpGfxSurface *gfx_surface,
   g_assert (!gfx_surface->render_surface);
 
   gfx_surface->render_surface = render_surface;
-  render_surface->is_auxiliary_surface = TRUE;
 }
 
 GrdRdpGfxFrameController *
