@@ -31,11 +31,13 @@ typedef struct _GrdClipboardVnc GrdClipboardVnc;
 typedef struct _GrdContext GrdContext;
 typedef struct _GrdCredentials GrdCredentials;
 typedef struct _GrdEglThread GrdEglThread;
+typedef struct _GrdEncodeContext GrdEncodeContext;
 typedef struct _GrdEncodeSession GrdEncodeSession;
 typedef struct _GrdHwAccelNvidia GrdHwAccelNvidia;
 typedef struct _GrdHwAccelVaapi GrdHwAccelVaapi;
 typedef struct _GrdHwAccelVulkan GrdHwAccelVulkan;
 typedef struct _GrdImageView GrdImageView;
+typedef struct _GrdLocalBuffer GrdLocalBuffer;
 typedef struct _GrdRdpAudioInput GrdRdpAudioInput;
 typedef struct _GrdRdpAudioOutputStream GrdRdpAudioOutputStream;
 typedef struct _GrdRdpAudioPlayback GrdRdpAudioPlayback;
@@ -69,6 +71,7 @@ typedef struct _GrdRdpSessionMetrics GrdRdpSessionMetrics;
 typedef struct _GrdRdpStreamOwner GrdRdpStreamOwner;
 typedef struct _GrdRdpSurface GrdRdpSurface;
 typedef struct _GrdRdpSurfaceRenderer GrdRdpSurfaceRenderer;
+typedef struct _GrdRdpSwEncoderCa GrdRdpSwEncoderCa;
 typedef struct _GrdRdpTelemetry GrdRdpTelemetry;
 typedef struct _GrdRdpViewCreator GrdRdpViewCreator;
 typedef struct _GrdSession GrdSession;
